@@ -1,8 +1,13 @@
+import sys
 from abc import abstractmethod
 from typing import AbstractSet, Dict, List, Optional, Sequence, Tuple
 
 from attr import Factory, attrib, attrs
-from typing_extensions import Protocol
+
+if sys.version_info < (3, 8):
+    from typing_extensions import Protocol
+else:
+    from typing import Protocol
 
 from seqscore.model import LabeledSequence, Mention, Span
 
@@ -179,6 +184,9 @@ class IO(Encoding):
     def repair_labels(self, labels: Sequence[str], method: str) -> Sequence[str]:
         raise NotImplementedError
 
+    def supported_repair_methods(self) -> Tuple[str, ...]:
+        return ()
+
     def decode_labels(self, labels: Sequence[str]) -> List[Mention]:
         builder = _MentionBuilder()
 
@@ -564,6 +572,9 @@ class BIOES(Encoding):
     def repair_labels(self, labels: Sequence[str], method: str) -> Sequence[str]:
         raise NotImplementedError
 
+    def supported_repair_methods(self) -> Tuple[str, ...]:
+        return ()
+
     def decode_labels(self, labels: Sequence[str]) -> List[Mention]:
         builder = _MentionBuilder()
 
